@@ -1,7 +1,7 @@
 package Farabi;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.32';
+# ABSTRACT: Modern Perl editor
 
 sub startup {
 	my $app = shift;
@@ -57,6 +57,7 @@ SQL
 }
 
 1;
+
 __END__
 
 =pod
@@ -65,6 +66,10 @@ __END__
 
 Farabi - Modern Perl editor
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   # Run on the default port 3000
@@ -140,9 +145,13 @@ Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
 
 Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
 
+=head1 AUTHOR
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2013 by Ahmad M. Zawawi
+This software is copyright (c) 2013 by Ahmad M. Zawawi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
