@@ -1,9 +1,8 @@
 package Farabi::Plugin::Debug;
 
+# ABSTRACT: Debugger support for Farabi
 use Moo;
 
-our $VERSION = '0.32';
-
 # Plugin module dependencies
 has 'deps' => (
 	is      => 'ro',
@@ -30,9 +29,17 @@ __END__
 
 Farabi::Plugin::Debug - Debugger support for Farabi
 
+=head1 VERSION
+
+version 0.33
+
+=head1 AUTHOR
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2013 by Ahmad M. Zawawi
+This software is copyright (c) 2013 by Ahmad M. Zawawi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
