@@ -1,8 +1,8 @@
 package Farabi::Plugin::PerlTidy;
 
-use Moo;
+# ABSTRACT: Perl::Tidy support for Farabi
 
-our $VERSION = '0.32';
+use Moo;
 
 # Plugin module dependencies
 has 'deps' => (
@@ -30,9 +30,17 @@ __END__
 
 Farabi::Plugin::PerlTidy - Perl::Tidy support for Farabi
 
+=head1 VERSION
+
+version 0.33
+
+=head1 AUTHOR
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2013 by Ahmad M. Zawawi
+This software is copyright (c) 2013 by Ahmad M. Zawawi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
